@@ -5,7 +5,7 @@ describe 'tempest' do
 
     let :pre_condition do
       "include ::glance
-       class { 'neutron': rabbit_password => 'passw0rd' }"
+       include ::neutron"
     end
 
     context 'without parameters' do
@@ -215,6 +215,8 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
           is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => false)
           is_expected.to contain_tempest_config('compute-feature-enabled/resize').with(:value => false)
+          is_expected.to contain_tempest_config('baremetal/driver').with(:value => 'fake')
+          is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => 'ipmi')
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
@@ -272,14 +274,15 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('whitebox/db_uri').with(:value => nil)
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
           is_expected.to contain_tempest_config('oslo_concurrency/lock_path').with(:value => '/var/lib/tempest')
-          is_expected.to contain_tempest_config('DEFAULT/debug').with(:value => false)
-          is_expected.to contain_tempest_config('DEFAULT/log_file').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_tempest_config('DEFAULT/use_stderr').with(:value => true)
-          is_expected.to contain_tempest_config('DEFAULT/use_syslog').with(:value => false)
-          is_expected.to contain_tempest_config('DEFAULT/logging_context_format_string').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('scenario/img_dir').with(:value => '/var/lib/tempest')
-          is_expected.to contain_tempest_config('scenario/img_file').with(:value => 'cirros-0.3.5-x86_64-disk.img')
+          is_expected.to contain_tempest_config('scenario/img_file').with(:value => 'cirros-0.4.0-x86_64-disk.img')
           is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => false)
+          is_expected.to contain_oslo__log('tempest_config').with(
+              :debug => false,
+              :log_file => '<SERVICE DEFAULT>',
+              :use_stderr => true,
+              :use_syslog => false,
+              :logging_context_format_string => '<SERVICE DEFAULT>')
 
           is_expected.not_to contain_tempest_config('magnum/keypair_id').with_value('default')
         end
@@ -360,7 +363,7 @@ describe 'tempest' do
   shared_examples 'tempest with plugins packages' do
     let :pre_condition do
       "include ::glance
-       class { 'neutron': rabbit_password => 'passw0rd' }"
+       include ::neutron"
     end
 
     context 'with when managing tests packages for keystone (required service)' do
@@ -407,6 +410,7 @@ describe 'tempest' do
         it { expect { is_expected.to contain_package('python-neutron-fwaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-lbaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-vpnaas-tests') } }
+        it { expect { is_expected.to contain_package('python-neutron-dynamic-routing-tests') } }
         it { expect { is_expected.to contain_package('python-networking-bgpvpn-tests-tempest') } }
         it { expect { is_expected.to contain_package('python-networking-l2gw-tests-tempest') } }
         it { expect { is_expected.to contain_package('python-horizon-tests-tempest') } }
